@@ -5,9 +5,7 @@ from mock import MagicMock
 
 from docutils import nodes
 
-from hieroglyph.tests.util import (
-    make_document,
-    with_sphinx,
+from sphinx_testing import (
     TestApp,
 )
 from hieroglyph.tests import util
@@ -18,8 +16,8 @@ from hieroglyph import directives
 
 class SlideConfTests(TestCase):
 
-    @with_sphinx()
-    def test_filter_doctree(self, sphinx_app):
+    @util.with_app()
+    def test_filter_doctree(self, sphinx_app, status, warning):
         """Only slide related elements will be retained when filtering."""
 
         test_content = """
@@ -42,7 +40,7 @@ Second Level
 
 """
 
-        document = make_document(
+        document = util.make_document(
             'slideconf_test',
             test_content,
         )
@@ -52,12 +50,11 @@ Second Level
         # only two elements remain -- the slideconf and slide element
         self.assertEqual(len(document.children), 2)
 
-    @with_sphinx(
+    @util.with_app(
         buildername='slides',
         srcdir=util.test_root.parent/'no-autoslides',
     )
-    def test_trailing_content_removed(self, sphinx_app):
-
+    def test_trailing_content_removed(self, sphinx_app, status, warning):
         sphinx_app.build()
 
         self.assertFalse(
@@ -77,7 +74,7 @@ class SlideTests(TestCase):
    Blarf
 """
 
-        document = make_document(
+        document = util.make_document(
             'slide_directive_test',
             test_content,
         )
@@ -100,7 +97,7 @@ class SlideTests(TestCase):
 Another Paragraph
 """
 
-        document = make_document(
+        document = util.make_document(
             'slide_directive_test',
             test_content,
         )
@@ -127,7 +124,7 @@ Another Paragraph
 Another Paragraph
 """
 
-        document = make_document(
+        document = util.make_document(
             'slide_directive_test',
             test_content,
         )
@@ -146,11 +143,11 @@ Another Paragraph
 
 class TestSlideConditions(TestCase):
 
-    @with_sphinx(
+    @util.with_app(
         buildername='html',
         srcdir=util.test_root,
     )
-    def test_slide_content_removed_when_building_html(self, sphinx_app):
+    def test_slide_content_removed_when_building_html(self, sphinx_app, status, warning):
 
         sphinx_app.build()
 
@@ -160,11 +157,11 @@ class TestSlideConditions(TestCase):
             self.assertIn('OTHERBUILDERS', html)
             self.assertNotIn('SLIDES', html)
 
-    @with_sphinx(
+    @util.with_app(
         buildername='slides',
         srcdir=util.test_root,
     )
-    def test_notslide_content_removed_when_building_slides(self, sphinx_app):
+    def test_notslide_content_removed_when_building_slides(self, sphinx_app, status, warning):
 
         sphinx_app.build()
 
@@ -174,15 +171,15 @@ class TestSlideConditions(TestCase):
             self.assertIn('SLIDES', html)
             self.assertNotIn('OTHERBUILDERS', html)
 
-    @with_sphinx(
+    @util.with_app(
         buildername='html',
         srcdir=util.test_root,
     )
-    def test_sections_in_cond_nodes_appear_in_toc(self, sphinx_app):
+    def test_sections_in_cond_nodes_appear_in_toc(self, sphinx_app, status, warning):
         sphinx_app.build()
 
         with open(sphinx_app.builddir/'html'/'index.html') as html_file:
-            tree = BeautifulSoup(html_file.read())
+            tree = BeautifulSoup(html_file.read(), "html.parser")
             contents = tree.find(
                 'div',
                 attrs=dict(id='contents'),
@@ -192,16 +189,18 @@ class TestSlideConditions(TestCase):
                 2,
             )
 
-    def test_builder_collision(self):
+    def test_builder_shared_doctreedirs(self):
 
         html_sphinx = TestApp(
-            buildername='slides',
-            srcdir=util.test_root,
-        )
-        slides_sphinx = TestApp(
             buildername='html',
             srcdir=util.test_root,
         )
+        slides_sphinx = TestApp(
+            buildername='slides',
+            srcdir=util.test_root,
+            doctreedir=html_sphinx.doctreedir,
+        )
+
         self.assertEqual(html_sphinx.doctreedir, slides_sphinx.doctreedir)
 
         try:
@@ -211,8 +210,8 @@ class TestSlideConditions(TestCase):
             with open(html_sphinx.builddir/'html'/'split_slides.html') as html_file:
                 with open(slides_sphinx.builddir/'slides'/'split_slides.html') as slide_file:
 
-                    html = BeautifulSoup(html_file.read())
-                    slides = BeautifulSoup(slide_file.read())
+                    html = BeautifulSoup(html_file.read(), "html.parser")
+                    slides = BeautifulSoup(slide_file.read(), "html.parser")
 
                     self.assertEqual(
                         len(html.find_all('h2')),
@@ -230,11 +229,11 @@ class TestSlideConditions(TestCase):
 
 class NextSlideTests(TestCase):
 
-    @with_sphinx(
+    @util.with_app(
         buildername='slides',
         srcdir=util.test_root,
     )
-    def test_nextslide_splits_content(self, sphinx_app):
+    def test_nextslide_splits_content(self, sphinx_app, status, warning):
 
         sphinx_app.build()
 
@@ -243,7 +242,7 @@ class NextSlideTests(TestCase):
         ) as html_file:
 
             slide_html = BeautifulSoup(
-                html_file.read()
+                html_file.read(), "html.parser"
             )
             slides = slide_html.find_all('article', class_='slide')
 
@@ -264,11 +263,11 @@ class NextSlideTests(TestCase):
                 'C Section',
             )
 
-    @with_sphinx(
+    @util.with_app(
         buildername='slides',
         srcdir=util.test_root,
     )
-    def test_copied_title(self, sphinx_app):
+    def test_copied_title(self, sphinx_app, status, warning):
 
         sphinx_app.build()
 
@@ -277,7 +276,7 @@ class NextSlideTests(TestCase):
         ) as html_file:
 
             slide_html = BeautifulSoup(
-                html_file.read()
+                html_file.read(), "html.parser"
             )
             slides = slide_html.find_all('article', class_='slide')[1:]
             first_title = slides[0].find('h2').text
@@ -289,11 +288,67 @@ class NextSlideTests(TestCase):
                     first_title,
                 )
 
-    @with_sphinx(
+    @util.with_app(
         buildername='slides',
         srcdir=util.test_root,
     )
-    def test_increment_slide_title(self, sphinx_app):
+    def test_nextslide_supports_nested_markup(self, sphinx_app, status, warning):
+        sphinx_app.build()
+
+        def inner_html(n):
+            return ''.join(
+                str(t) for t in n.contents
+            )
+
+        with open(
+            sphinx_app.builddir/'slides'/'nextslide_nested_markup.html'
+        ) as html_file:
+
+            slide_html = BeautifulSoup(
+                html_file.read(), "html.parser"
+            )
+            slides = slide_html.find_all('article', class_='slide')[1:]
+            first_title = inner_html(slides[0].find('h2'))
+
+            for idx, slide in enumerate(slides[1:]):
+                title = inner_html(slide.find('h2'))
+                self.assertEqual(
+                    title,
+                    '%s (%d)' % (first_title, idx+2),
+                )
+
+    @util.with_app(
+        buildername='slides',
+        srcdir=util.test_root,
+    )
+    def test_nextslide_allows_explicit_title(self, sphinx_app, status, warning):
+        sphinx_app.build()
+
+        def inner_html(n):
+            return ''.join(
+                str(t) for t in n.contents
+            )
+
+        with open(
+            sphinx_app.builddir/'slides'/'nextslide_explicit_title.html'
+        ) as html_file:
+
+            slide_html = BeautifulSoup(
+                html_file.read(), "html.parser"
+            )
+            slides = slide_html.find_all('article', class_='slide')[1:]
+            first_title = inner_html(slides[0].find('h2'))
+            second_title = inner_html(slides[1].find('h2'))
+
+            self.assertNotEqual(first_title, second_title)
+            self.assertEqual(first_title, '<em>Slide</em> Title')
+            self.assertEqual(second_title, '<strong>Slide</strong> Title')
+
+    @util.with_app(
+        buildername='slides',
+        srcdir=util.test_root,
+    )
+    def test_increment_slide_title(self, sphinx_app, status, warning):
 
         sphinx_app.build()
 
@@ -302,7 +357,7 @@ class NextSlideTests(TestCase):
         ) as html_file:
 
             slide_html = BeautifulSoup(
-                html_file.read()
+                html_file.read(), "html.parser"
             )
             slides = slide_html.find_all('article', class_='slide')[1:]
             first_title = slides[0].find('h2').text
@@ -319,9 +374,13 @@ class TransformNextSlideTests(TestCase):
 
     def setUp(self):
 
-        self.app = TestApp(buildername='slides')
-        self.builder = SlideBuilder(self.app)
-        self.document = make_document(
+        self.app = TestApp(
+            buildername='slides',
+            copy_srcdir_to_tmpdir=True,
+            srcdir=util.test_root,
+        )
+        self.builder = self.app.builder
+        self.document = util.make_document(
             'testing',
             """\
 Slide Title
@@ -330,7 +389,8 @@ Slide Title
 * Bullet 1
 * Bullet 2
 
-.. nextslide::
+.. nextslide:: **Title**
+   :classes: extra-class
 
 Additional Text
 
@@ -338,7 +398,7 @@ Additional Text
         )
         self.builder.init_templates()
 
-    def test_visit_slide_creates_new_slide_data(self):
+    def test_next_slide_transformer_ignores_nonslide_builds(self):
 
         self.assertEqual(
             len(self.document.traverse(nodes.section)),
@@ -356,3 +416,40 @@ Additional Text
             len(self.document.traverse(nodes.section)),
             1,
         )
+
+    def test_next_slide_creates_new_sections(self):
+
+        self.assertEqual(
+            len(self.document.traverse(nodes.section)),
+            1,
+        )
+
+        transformer = directives.TransformNextSlides(self.document)
+        transformer.apply_to_document(
+            self.document,
+            env=MagicMock(),
+            building_slides=True,
+        )
+
+        self.assertEqual(
+            len(self.document.traverse(nodes.section)),
+            2,
+        )
+        self.assertIn(
+            'extra-class',
+            self.document.traverse(nodes.section)[-1].get('classes'),
+        )
+
+    def test_nested_title_markup(self):
+
+        transformer = directives.TransformNextSlides(self.document)
+        transformer.apply_to_document(
+            self.document,
+            env=MagicMock(),
+            building_slides=True,
+        )
+
+        self.assertEqual(
+            str(self.document.traverse(nodes.section)[1][0]),
+            '<title><strong>Title</strong></title>',
+        )
